import { useForm } from "react-hook-form";
import { Box, Button, Typography, Modal } from "@mui/material";
import CloseIcon from "@mui/icons-material/Close";
import {
	CustomIconButton,
	CustomTextField,
} from "../AddEditUserModel/styled.css.tsx"; // Assuming custom styled components

export default function AddStationModal({
	open,
	handleClose,
	handleAddStation,
}) {
	const {
		register,
		handleSubmit,
		formState: { errors },
		reset,
	} = useForm();

	const onSubmit = (data: any) => {
		handleAddStation(data); // Add station to the list
		handleClose(); // Close modal after adding
		reset();
	};

	return (
		<Modal
			open={open}
			onClose={(e, reason) => {
				if (reason === "backdropClick") {
					return;
				}
				handleClose(); // Close modal when clicking cross or cancel
			}}
			aria-labelledby="add-station-modal"
		>
			<Box
				sx={{
					position: "absolute",
					top: "50%",
					left: "50%",
					transform: "translate(-50%, -50%)",
					width: 400,
					bgcolor: "background.paper",
					boxShadow: 24,
					p: 3,
					borderRadius: 2,
				}}
			>
				{/* Header */}
				<Box
					sx={{
						display: "flex",
						justifyContent: "space-between",
						alignItems: "center",
					}}
				>
					<Typography variant="h6" fontWeight={600}>
						Add Charging Station
					</Typography>
					<CustomIconButton onClick={handleClose}>
						<CloseIcon />
					</CustomIconButton>
				</Box>

				{/* Horizontal Line */}
				<Box sx={{ borderBottom: "1px solid #ddd", my: 2 }} />

				{/* Form */}
				<form onSubmit={handleSubmit(onSubmit)}>
					{/* Input Fields */}
					<Box
						sx={{
							display: "flex",
							flexDirection: "column",
							gap: 2,
						}}
					>
						{/* First Row - Two Inputs */}
						<Box sx={{ display: "flex", gap: 2 }}>
							<Box
								sx={{
									display: "flex",
									flexDirection: "column",
									width: "100%",
								}}
							>
								<Typography variant="body2" fontWeight={500}>
									Station Name
								</Typography>
								<CustomTextField
									fullWidth
									placeholder="Enter Station Name"
									size="small"
									error={!!errors.name}
									helperText={
										errors.name ? errors.name.message : ""
									}
									{...register("name", {
										required: "Station Name is required",
										minLength: {
											value: 3,
											message:
												"Minimum 3 characters required",
										},
										maxLength: {
											value: 30,
											message:
												"Maximum 30 characters allowed",
										},
									})}
								/>
							</Box>

							<Box
								sx={{
									display: "flex",
									flexDirection: "column",
									width: "100%",
								}}
							>
								<Typography variant="body2" fontWeight={500}>
									Station Location
								</Typography>
								<CustomTextField
									fullWidth
									placeholder="Enter Charging Station Address"
									size="small"
									error={!!errors.registeredAddress}
									helperText={
										errors.registeredAddress
											? errors.registeredAddress.message
											: ""
									}
									{...register("registeredAddress", {
										required:
											"Registered Address is required",
									})}
								/>
							</Box>
						</Box>

						{/* Second Row - Total Slots */}
						<Box sx={{ display: "flex", gap: 2 }}>
							<Box
								sx={{
									display: "flex",
									flexDirection: "column",
									width: "100%",
								}}
							>
								<Typography variant="body2" fontWeight={500}>
									Total Slots
								</Typography>
								<CustomTextField
									fullWidth
									placeholder="Enter Total Slots"
									size="small"
									type="number"
									error={!!errors.totalSlots}
									helperText={
										errors.totalSlots
											? errors.totalSlots.message
											: ""
									}
									{...register("totalSlots", {
										required: "Total Slots are required",
										min: {
											value: 1,
											message:
												"At least 1 slot is required",
										},
									})}
								/>
							</Box>
						</Box>
					</Box>

					{/* Submit Button */}
					<Box
						sx={{
							display: "flex",
							justifyContent: "flex-end",
							mt: 3,
						}}
					>
						<Button
							type="submit"
							sx={{
								backgroundColor: "#52ACDF",
								color: "white",
								borderRadius: "8px",
								width: "117px",
								"&:hover": { backgroundColor: "#439BC1" },
							}}
						>
							Add Station
						</Button>
					</Box>
				</form>
			</Box>
		</Modal>
	);
}
