import React, { useEffect, useState } from "react";
import { Box, Modal, Typography, Divider, Grid } from "@mui/material";
import CloseIcon from "@mui/icons-material/Close";
import { useSelector } from "react-redux";
import { RootState } from "../../../redux/reducers";

type Props = {
	open: boolean;
	setViewModal: Function;
	handleView: (id: string | undefined) => void;
	id?: string | undefined;
};

const style = {
	position: "absolute",
	top: "50%",
	left: "50%",
	transform: "translate(-50%, -50%)",
	width: 400,
	bgcolor: "background.paper",
	borderRadius: 2,
	boxShadow: "0px 4px 20px rgba(0, 0, 0, 0.15)",
	p: 4,
	display: "flex",
	flexDirection: "column",
	alignItems: "center",
	gap: 2,
};

export default function UserViewModal({ open, setViewModal, id }: Props) {
	const { users } = useSelector(
		(state: RootState) => state.userReducer // Assuming users are stored in userReducer
	);
	const [selectedUser, setSelectedUser] = useState<any>(null);

	useEffect(() => {
		if (id) {
			const user = users.find((user) => user.id === id);
			setSelectedUser(user || null);
		}
	}, [id, users]);

	return (
		<Modal
			open={open}
			aria-labelledby="modal-title"
			aria-describedby="modal-description"
		>
			<Box sx={style}>
				<Typography
					id="modal-title"
					variant="h5"
					fontWeight="bold"
					sx={{ width: "100%" }}
				>
					<Box
						sx={{
							display: "flex",
							alignItems: "center",
							justifyContent: "space-between",
							width: "100%",
						}}
					>
						<Box sx={{ flex: 1, textAlign: "center" }}>
							{selectedUser?.name || "User"}'s Details
						</Box>
						<Box
							onClick={() => setViewModal(false)}
							sx={{
								cursor: "pointer",
								display: "flex",
								alignItems: "center",
							}}
						>
							<CloseIcon />
						</Box>
					</Box>
				</Typography>

				<Divider sx={{ width: "100%" }} />

				{selectedUser ? (
					<Grid container spacing={2} sx={{ width: "80%" }}>
						<Grid item xs={6}>
							<Typography variant="body1">
								<strong>Name:</strong>{" "}
								<Typography variant="body2">
									{selectedUser.name}
								</Typography>
							</Typography>
						</Grid>
						<Grid item xs={6}>
							<Typography variant="body1">
								<strong>Email:</strong>{" "}
								<Typography variant="body2">
									{selectedUser.email}
								</Typography>
							</Typography>
						</Grid>
						<Grid item xs={6}>
							<Typography variant="body1">
								<strong>Phone:</strong>{" "}
								<Typography variant="body2">
									{selectedUser.phone ?? "N/A"}
								</Typography>
							</Typography>
						</Grid>
					</Grid>
				) : (
					<Typography align="center">
						No user found with this ID
					</Typography>
				)}
			</Box>
		</Modal>
	);
}
